/*
  A reference to a branch mapping known to the system.

*/
function BranchesCommand(data) {

    Object.defineProperties(this, {
        /*
          The branch name, as provided on the command line.
        */
        "branch": {
            value: data ? data.branch : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The owner of the branch mapping.
          By default, this will be set to the user who created the branch.
          This field is unimportant unless the Option: field value is locked.

        */
        "owner": {
            value: data ? data.owner : undefined,
            enumerable: true,
            writable: true
        },
        /*
          The date the branch mapping was last accessed.
        */
        "access": {
            enumerable: true,
            get: function() {
                if (data && data.access) {
                    var strVal = data.access;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          The date the branch mapping was last changed.
        */
        "update": {
            enumerable: true,
            get: function() {
                if (data && data.update) {
                    var strVal = data.update;
                    return Date.parse(strVal);
                }
            }
        },
        /*
          Either `unlocked` (the default) or `locked`.

          If `locked`, only the `Owner:` can modify the branch mapping, and the mapping can't be deleted until it is `unlocked`.

        */
        "options": {
            value: data ? data.options : undefined,
            enumerable: true,
            writable: true
        },
        /*
          A short description of the branch's purpose.
        */
        "description": {
            value: data ? data.description : undefined,
            enumerable: true,
            writable: true
        }
    });

}

module.exports = BranchesCommand;
